Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2434)

Unified Diff: chrome/browser/spellchecker/spelling_service_client.cc

Issue 1156473007: Enables the user to select multiple languages for spellchecking (UI) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed bug and added a test for it. Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/spellchecker/spelling_service_client.cc
diff --git a/chrome/browser/spellchecker/spelling_service_client.cc b/chrome/browser/spellchecker/spelling_service_client.cc
index a0c1381cbb9a0eb9254982a6e9b02948f5181254..0ce3b6b9deb1e5952ac8023ae80a0f325766dbd2 100644
--- a/chrome/browser/spellchecker/spelling_service_client.cc
+++ b/chrome/browser/spellchecker/spelling_service_client.cc
@@ -105,11 +105,13 @@ bool SpellingServiceClient::IsAvailable(
ServiceType type) {
const PrefService* pref = user_prefs::UserPrefs::Get(context);
DCHECK(pref);
// If prefs don't allow spellchecking or if the context is off the record,
// the spelling service should be unavailable.
if (!pref->GetBoolean(prefs::kEnableContinuousSpellcheck) ||
!pref->GetBoolean(prefs::kSpellCheckUseSpellingService) ||
- context->IsOffTheRecord())
+ context->IsOffTheRecord() ||
+ chrome::spellcheck_common::IsMultilingualSpellcheckEnabled())
return false;
// If the locale for spelling has not been set, the user has not decided to
@@ -105,11 +105,13 @@ bool SpellingServiceClient::IsAvailable(
const PrefService* pref = user_prefs::UserPrefs::Get(context);
DCHECK(pref);
- // If prefs don't allow spellchecking or if the context is off the record,
- // the spelling service should be unavailable.
+ // If prefs don't allow spellchecking, if the context is off the record, or if
+ // multilingual spellchecking is enabled the spelling service should be
+ // unavailable.
if (!pref->GetBoolean(prefs::kEnableContinuousSpellcheck) ||
!pref->GetBoolean(prefs::kSpellCheckUseSpellingService) ||

Powered by Google App Engine
This is Rietveld 408576698